@@ -2,6 +2,7 @@ package oauth2
 
 import (
 	"context"
+	"crypto/tls"
 	"encoding/base64"
 	"encoding/json"
 	"fmt"
@@ -51,43 +52,46 @@ const CodeVerifierLength = 43
 var CodeChallengeEncoder = base64.RawURLEncoding
 
 type ClientConfig struct {
-	IssuerURL              string
-	RedirectURL            string
-	GrantType              string
+	IssuerURL              string `validate:"url"`
+	RedirectURL            string `validate:"url"`
+	GrantType              string `validate:"oneof=authorization_code client_credentials implicit password refresh_token urn:ietf:params:oauth:grant-type:jwt-bearer urn:ietf:params:oauth:grant-type:token-exchange urn:ietf:params:oauth:grant-type:device_code"`
 	ClientID               string
 	ClientSecret           string
 	Scopes                 []string
 	ACRValues              []string
 	Audience               []string
-	AuthMethod             string
+	AuthMethod             string `validate:"omitempty,oneof=client_secret_basic client_secret_post client_secret_jwt private_key_jwt self_signed_tls_client_auth tls_client_auth none"`
 	PKCE                   bool
 	PAR                    bool
 	RequestObject          bool
 	EncryptedRequestObject bool
 	Insecure               bool
-	ResponseType           []string
-	ResponseMode           string
+	ResponseType           []string `validate:"dive,omitempty,oneof=code id_token token"`
+	ResponseMode           string   `validate:"omitempty,oneof=query form_post query.jwt form_post.jwt jwt"`
 	Username               string
 	Password               string
 	RefreshToken           string
-	Assertion              string
-	SigningKey             string
-	EncryptionKey          string
+	Assertion              string `validate:"omitempty,json"`
+	SigningKey             string `validate:"omitempty,uri"`
+	EncryptionKey          string `validate:"omitempty,uri"`
 	SubjectToken           string
-	SubjectTokenType       string
+	SubjectTokenType       string `validate:"omitempty,oneof=urn:ietf:params:oauth:token-type:access_token"`
 	ActorToken             string
-	ActorTokenType         string
+	ActorTokenType         string `validate:"omitempty,oneof=urn:ietf:params:oauth:token-type:access_token"`
 	IDTokenHint            string
 	LoginHint              string
 	IDPHint                string
-	TLSCert                string
-	TLSKey                 string
-	TLSRootCA              string
+	TLSCert                string `validate:"omitempty,uri"`
+	TLSKey                 string `validate:"omitempty,uri"`
+	TLSRootCA              string `validate:"omitempty,uri"`
+	CallbackTLSCert        string `validate:"omitempty,uri"`
+	CallbackTLSKey         string `validate:"omitempty,uri"`
 	HTTPTimeout            time.Duration
 	BrowserTimeout         time.Duration
 	DPoP                   bool
-	Claims                 string
-	RAR                    string
+	Claims                 string `validate:"omitempty,json"`
+	RAR                    string `validate:"omitempty,json"`
+	Purpose                string
 }
 
 func RequestAuthorization(cconfig ClientConfig, sconfig ServerConfig, hc *http.Client) (r Request, codeVerifier string, err error) {
@@ -191,6 +195,7 @@ func WaitForCallback(clientConfig ClientConfig, serverConfig ServerConfig, hc *h
 	var (
 		srv         = http.Server{}
 		redirectURL *url.URL
+		cert        tls.Certificate
 		done        = make(chan struct{})
 	)
 
@@ -204,6 +209,16 @@ func WaitForCallback(clientConfig ClientConfig, serverConfig ServerConfig, hc *h
 		redirectURL.Path = "/"
 	}
 
+	if redirectURL.Scheme == "https" {
+		if cert, err = ReadKeyPair(clientConfig.CallbackTLSCert, clientConfig.CallbackTLSKey, hc); err != nil {
+			return request, errors.Wrapf(err, "failed to read callback tls key pair")
+		}
+
+		srv.TLSConfig = &tls.Config{
+			Certificates: []tls.Certificate{cert},
+		}
+	}
+
 	http.HandleFunc(redirectURL.Path, func(w http.ResponseWriter, r *http.Request) {
 		defer func() {
 			time.AfterFunc(time.Second, func() {
@@ -272,8 +287,14 @@ func WaitForCallback(clientConfig ClientConfig, serverConfig ServerConfig, hc *h
 	go func() {
 		defer close(done)
 
-		if serr := srv.ListenAndServe(); serr != http.ErrServerClosed {
-			err = serr
+		if redirectURL.Scheme == "https" {
+			if serr := srv.ListenAndServeTLS("", ""); serr != http.ErrServerClosed {
+				err = serr
+			}
+		} else {
+			if serr := srv.ListenAndServe(); serr != http.ErrServerClosed {
+				err = serr
+			}
 		}
 	}()
 
